@@ -1,5 +1,4 @@
-
-#                        Copyright (c) 2021 Zenqi
+# Copyright (c) 2021 Zenqi
 
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -19,8 +18,9 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-__description__ = "A simple secure database for storing data."
-__author__ = "Zenqi"
-__version__ = "0.0.0"
-__license__ = "MIT"
-__copyright__ = "Copyright (c) 2021, Zenqi. All rights reserved."
+from lemondb.database import LemonDB
+from lemondb.query import Query
+
+
+__version__ = "0.0.1"
+__all__ = ['LemonDB', 'Query']
